The code files in this directory are directly taken from (or modified from) that found in the prosit code base (found here: https://github.com/kusterlab/prosit/) and licensed under Apache License 2.0

According to the zenodo citation at the time of adaptation, the following authors are credited with the original code:

"creators": [
        {
            "affiliation": "Chair of Proteomics and Bioanalytics, Technical University of Munich, Germany",
            "name": "Siegfried Gessulat",
          "orcid": "0000-0001-5530-0674"
        },
        {
            "affiliation": "Chair of Proteomics and Bioanalytics, Technical University of Munich, Germany",
            "name": "Tobias Schmidt",
          "orcid": "0000-0002-1883-6514"
        },
        {
            "affiliation": "Chair of Proteomics and Bioanalytics, Technical University of Munich, Germany",
            "name": "Mathias Wilhelm",
          "orcid": "0000-0002-9224-3258"
        },
        {
            "affiliation": "Chair of Proteomics and Bioanalytics, Technical University of Munich, Germany",
            "name": "Bernhard Kuster",
          "orcid": "0000-0002-9094-1677"
        }
]

Note that since then parts of the code have been completely changed or new functions added.
